==> oras-cli-1.0.1.tar.gz: oras-1.0.1/test/e2e/scripts/e2e.sh <==
#!/bin/sh -e

# Copyright The ORAS Authors.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

export ORAS_REGISTRY_PORT="5000"
export ORAS_REGISTRY_HOST="localhost:${ORAS_REGISTRY_PORT}"
export ORAS_REGISTRY_FALLBACK_PORT="6000"
export ORAS_REGISTRY_FALLBACK_HOST="localhost:${ORAS_REGISTRY_FALLBACK_PORT}"

repo_root=$1
if [ -z "${repo_root}" ]; then
    echo "repository root path is not provided."
    echo "Usage"
    echo "  e2e.sh <repo_root> [--clean]"
    exit 1
fi
clean_up=$2

echo " === installing ginkgo  === "
repo_root=$(realpath --canonicalize-existing ${repo_root})
cwd=$(pwd)
cd ${repo_root}/test/e2e && go install github.com/onsi/ginkgo/v2/ginkgo@latest
trap "cd $cwd" EXIT

# start registries
. ${repo_root}/test/e2e/scripts/common.sh

if [ "$clean_up" = '--clean' ]; then
    echo " === setting deferred clean up jobs  === "
    trap "try_clean_up oras-e2e oras-e2e-fallback" EXIT
fi

oras_container_name="oras-e2e"
upstream_container_name="oras-e2e-fallback"
e2e_root="${repo_root}/test/e2e"
echo " === preparing oras distribution === "
run_registry \
  ${e2e_root}/testdata/distribution/mount \
  ghcr.io/oras-project/registry:v1.0.0-rc.4 \
  $oras_container_name \
  $ORAS_REGISTRY_PORT

echo " === preparing upstream distribution === "
run_registry \
  ${e2e_root}/testdata/distribution/mount_fallback \
  registry:2.8.1 \
  $upstream_container_name \
  $ORAS_REGISTRY_FALLBACK_PORT

echo " === run tests === "
if ! ginkgo -r -p --succinct suite; then 
  echo " === retriving registry error logs === "
  echo '-------- oras distribution trace -------------'
  docker logs -t --tail 200 $oras_container_name
  echo '-------- upstream distribution trace -------------'
  docker logs -t --tail 200 $upstream_container_name
  exit 1
fi

==> oras-cli-1.2.3.tar.gz: oras-1.2.3/test/e2e/scripts/e2e.sh <==
#!/bin/sh -e

# Copyright The ORAS Authors.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# help
help () {
    echo "Usage"
    echo "  e2e.sh <repo_root> [--clean]"
    exit 1
}

# 1. Prepare
repo_root=$1
if [ -z "${repo_root}" ]; then
    echo "repository root path is not provided."
    help
fi

clean=$2
if [ "${clean}" != '--clean' ] && [ -n "${clean}" ]; then
    echo "invalid flag found: ${clean}"
    help
fi

. ${repo_root}/test/e2e/scripts/prepare.sh $1 $2

if [ "${clean}" = '--clean' ]; then
    echo " === setting deferred clean up jobs  === "
    trap "try_clean_up $ORAS_CTR_NAME $UPSTREAM_CTR_NAME $ZOT_CTR_NAME" EXIT
fi

# 2. Test
echo " === run tests === "
if ! ginkgo -r -p --succinct suite; then 
  echo " === retriving registry error logs === "
  echo '-------- oras distribution trace -------------'
  docker logs -t --tail 200 $ORAS_CTR_NAME
  echo '-------- upstream distribution trace -------------'
  docker logs -t --tail 200 $UPSTREAM_CTR_NAME
  echo '-------- zot trace -------------'
  docker logs -t --tail 200 $ZOT_CTR_NAME
  exit 1
fi
